<?php

declare(strict_types=1);

namespace Drupal\external_roles\Cache\Context;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\external_roles\Service\ExternalRolesInterface;

/**
 * Defines the external roles cache context.
 */
class ExternalRolesCacheContext implements CacheContextInterface {

  /**
   * Constructs a new ExternalRolesCacheContext object.
   */
  public function __construct(
    protected AccountProxyInterface $currentUser,
    protected ExternalRolesInterface $externalRoles,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getLabel(): TranslatableMarkup|string {
    return t('User External Roles');
  }

  /**
   * {@inheritdoc}
   */
  public function getContext(): string {
    $account = $this->currentUser->getAccount();
    return implode(',', $this->externalRoles->getExternalRoles($account));
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata(): CacheableMetadata {
    $account = $this->currentUser->getAccount();
    return (new CacheableMetadata())->addCacheableDependency($account);
  }

}
