<?php

declare(strict_types=1);

namespace Drupal\external_roles;

use Drupal\Core\Session\AccessPolicyBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\CalculatedPermissionsItem;
use Drupal\Core\Session\RefinableCalculatedPermissionsInterface;
use Drupal\external_roles\Service\ExternalRolesInterface;

/**
 * Grants permissions based on a user's external roles.
 */
final class ExternalRolesAccessPolicy extends AccessPolicyBase {

  /**
   * Constructs a new ExternalRolesAccessPolicy object.
   */
  public function __construct(
    protected ExternalRolesInterface $externalRoles,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function calculatePermissions(AccountInterface $account, string $scope): RefinableCalculatedPermissionsInterface {
    $calculated_permissions = parent::calculatePermissions($account, $scope);
    $external_permissions = $this->externalRoles->getPermissions($account);
    $calculated_permissions->addItem(new CalculatedPermissionsItem($external_permissions));
    return $calculated_permissions;
  }

  /**
   * {@inheritdoc}
   */
  public function getPersistentCacheContexts(): array {
    return ['user.external_roles'];
  }

}
