<?php

declare(strict_types=1);

namespace Drupal\external_roles;

use Drupal\Core\Site\Settings;

/**
 * Provides the external roles repository.
 */
class ExternalRolesRepository implements ExternalRolesRepositoryInterface {

  /**
   * The external roles and permission definition.
   */
  protected array $definition;

  /**
   * {@inheritdoc}
   */
  public function getPermissionsByRole(string $role): array {
    return $this->loadDefinition()[$role]['permissions'] ?? [];
  }

  /**
   * Loads the external roles and permission definition from settings.
   *
   * The roles are configured in settings.php using $settings['external_roles'].
   * The array structure for this configuration is defined as follows.
   *
   * [
   *   '{role}' => [
   *     'name' => '...',
   *     'permissions' => [
   *       '...',
   *       '...',
   *       '...',
   *     ],
   *   ],
   *   '{role}' => ...,
   *   '{role}' => ...,
   * ];
   *
   * @return array
   *   An array that defines external roles and permissions.
   */
  protected function loadDefinition(): array {
    if (!isset($this->definition)) {
      $this->definition = Settings::get('external_roles', []);
    }
    return $this->definition;
  }

}
