<?php

declare(strict_types=1);

namespace Drupal\external_roles\Service;

use Drupal\Core\Session\AccountInterface;

/**
 * Provides an interface for the external roles service.
 */
interface ExternalRolesInterface {

  /**
   * Gets the external roles of the user.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user account.
   *
   * @return string[]
   *   An array of sorted external roles.
   */
  public function getExternalRoles(AccountInterface $account): array;

  /**
   * Gets the permissions associated with the external roles of the user.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user account.
   *
   * @return string[]
   *   An array of permissions.
   */
  public function getPermissions(AccountInterface $account): array;

}
